__title__ = 'aiopogo'
__version__ = '1.7.1'
__author__ = 'David Christenson'
__license__ = 'MIT License'
__copyright__ = 'Copyright (c) 2017 David Christenson <https://github.com/Noctem>'

from .exceptions import PleaseInstallProtobufVersion3

try:
    from google import protobuf as _protobuf
    protobuf_version = _protobuf.__version__
except ImportError:
    raise PleaseInstallProtobufVersion3('Protobuf not found, install it.')

if int(protobuf_version[:1]) < 3:
    raise PleaseInstallProtobufVersion3('Protobuf 3 needed, you have {}'.format(protobuf_version))

from functools import partial as _partial
from logging import getLogger as _getLogger

try:
    from ujson import dumps as _dumps, loads as json_loads
    json_dumps = _partial(_dumps, escape_forward_slashes=False)
except ImportError:
    from json import dumps as _dumps, loads as json_loads
    from .utilities import JSONByteEncoder
    json_dumps = _partial(_dumps, cls=JSONByteEncoder)

from .pgoapi import PGoApi
from .rpc_api import RpcApi
from .hash_server import HashServer

_getLogger('aiohttp.client').setLevel(40)

def close_sessions():
    RpcApi.sessions.close()
    HashServer.close_session()

def activate_hash_server(hash_token, conn_limit=300):
    HashServer.set_token(hash_token)
    HashServer.activate_session(conn_limit)
